/// <reference types="node" />
import sharp from 'sharp';
import { z } from 'zod';
import { SharpOperations } from '.';
import { CloudEvent } from '@project-lakechain/sdk';
declare function Sharp(options?: sharp.SharpOptions): sharp.Sharp;
declare function Sharp(input?: Buffer | ArrayBuffer | Uint8Array | Uint8ClampedArray | Int8Array | Uint16Array | Int16Array | Uint32Array | Int32Array | Float32Array | Float64Array | string, options?: sharp.SharpOptions): sharp.Sharp;
/**
 * The type associated with the Sharp function.
 */
export type SharpFunction = typeof Sharp;
/**
 * A function expression that executes the Sharp funclet evaluation.
 * @param event the cloud event to process.
 * @param sharp the sharp instance to apply the transformations to.
 * @returns a promise resolving to a boolean value.
 */
export type IntentExpression = (event: CloudEvent, sharp: SharpFunction) => AsyncGenerator<sharp.Sharp, void, any>;
/**
 * The properties for the Sharp image transform middleware.
 */
export declare const SharpImageTransformSchema: z.ZodObject<z.objectUtil.extendShape<{
    sources: z.ZodType<Set<import("@project-lakechain/core/middleware").Middleware>, z.ZodTypeDef, Set<import("@project-lakechain/core/middleware").Middleware>>;
    /**
     * The properties for the Sharp image transform middleware.
     */
    destinations: z.ZodType<Set<import("@project-lakechain/core/middleware").Middleware>, z.ZodTypeDef, Set<import("@project-lakechain/core/middleware").Middleware>>; /**
     * The transformations to perform on the image.
     */
    conditionals: z.ZodMap<z.ZodString, z.ZodType<import("@project-lakechain/core").ConditionalStatement, z.ZodTypeDef, import("@project-lakechain/core").ConditionalStatement>>;
    computeType: z.ZodOptional<z.ZodDefault<z.ZodNativeEnum<typeof import("@project-lakechain/core").ComputeType>>>;
    maxRetry: z.ZodOptional<z.ZodDefault<z.ZodNumber>>;
    queueVisibilityTimeout: z.ZodOptional<z.ZodDefault<z.ZodType<import("aws-cdk-lib").Duration, z.ZodTypeDef, import("aws-cdk-lib").Duration>>>;
    batchingWindow: z.ZodOptional<z.ZodEffects<z.ZodType<import("aws-cdk-lib").Duration, z.ZodTypeDef, import("aws-cdk-lib").Duration>, import("aws-cdk-lib").Duration, import("aws-cdk-lib").Duration>>;
    batchSize: z.ZodOptional<z.ZodNumber>;
    maxConcurrency: z.ZodOptional<z.ZodNumber>;
    cloudWatchInsights: z.ZodDefault<z.ZodBoolean>;
    cacheStorage: z.ZodType<import("@project-lakechain/core").CacheStorage, z.ZodTypeDef, import("@project-lakechain/core").CacheStorage>;
    logRetention: z.ZodDefault<z.ZodType<import("aws-cdk-lib/aws-logs").RetentionDays, z.ZodTypeDef, import("aws-cdk-lib/aws-logs").RetentionDays>>;
    maxMemorySize: z.ZodOptional<z.ZodNumber>;
    kmsKey: z.ZodOptional<z.ZodType<import("aws-cdk-lib/aws-kms").IKey, z.ZodTypeDef, import("aws-cdk-lib/aws-kms").IKey>>;
    keyReusePeriod: z.ZodDefault<z.ZodType<import("aws-cdk-lib").Duration, z.ZodTypeDef, import("aws-cdk-lib").Duration>>;
    vpc: z.ZodOptional<z.ZodType<import("aws-cdk-lib/aws-ec2").IVpc, z.ZodTypeDef, import("aws-cdk-lib/aws-ec2").IVpc>>;
}, {
    /**
     * The transformations to perform on the image.
     */
    sharpTransforms: z.ZodUnion<[z.ZodType<SharpOperations, z.ZodTypeDef, SharpOperations>, z.ZodType<IntentExpression, z.ZodTypeDef, IntentExpression>]>;
}>, "strip", z.ZodTypeAny, {
    logRetention: import("aws-cdk-lib/aws-logs").RetentionDays;
    sources: Set<import("@project-lakechain/core/middleware").Middleware>;
    destinations: Set<import("@project-lakechain/core/middleware").Middleware>;
    conditionals: Map<string, import("@project-lakechain/core").ConditionalStatement>;
    cloudWatchInsights: boolean;
    cacheStorage: import("@project-lakechain/core").CacheStorage;
    keyReusePeriod: import("aws-cdk-lib").Duration;
    sharpTransforms: SharpOperations | IntentExpression;
    kmsKey?: import("aws-cdk-lib/aws-kms").IKey | undefined;
    vpc?: import("aws-cdk-lib/aws-ec2").IVpc | undefined;
    computeType?: import("@project-lakechain/core").ComputeType | undefined;
    maxRetry?: number | undefined;
    queueVisibilityTimeout?: import("aws-cdk-lib").Duration | undefined;
    batchingWindow?: import("aws-cdk-lib").Duration | undefined;
    batchSize?: number | undefined;
    maxConcurrency?: number | undefined;
    maxMemorySize?: number | undefined;
}, {
    sources: Set<import("@project-lakechain/core/middleware").Middleware>;
    destinations: Set<import("@project-lakechain/core/middleware").Middleware>;
    conditionals: Map<string, import("@project-lakechain/core").ConditionalStatement>;
    cacheStorage: import("@project-lakechain/core").CacheStorage;
    sharpTransforms: SharpOperations | IntentExpression;
    kmsKey?: import("aws-cdk-lib/aws-kms").IKey | undefined;
    vpc?: import("aws-cdk-lib/aws-ec2").IVpc | undefined;
    logRetention?: import("aws-cdk-lib/aws-logs").RetentionDays | undefined;
    computeType?: import("@project-lakechain/core").ComputeType | undefined;
    maxRetry?: number | undefined;
    queueVisibilityTimeout?: import("aws-cdk-lib").Duration | undefined;
    batchingWindow?: import("aws-cdk-lib").Duration | undefined;
    batchSize?: number | undefined;
    maxConcurrency?: number | undefined;
    cloudWatchInsights?: boolean | undefined;
    maxMemorySize?: number | undefined;
    keyReusePeriod?: import("aws-cdk-lib").Duration | undefined;
}>;
export type SharpImageTransformProps = z.infer<typeof SharpImageTransformSchema>;
export {};
